<h1>
  <img src="https://github.com/jpsca/jinjax/raw/main/jinjax-logo.png" height="50" align="top">
</h1>

From chaos to clarity: The power of components in your server-side-rendered Python web app.

**Documentation:** https://jinjax.scaletti.dev/

Write server-side components as single Jinja template files.
Use them as HTML tags without doing any importing.
